{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.17--ha92aebf_3",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.sequences)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "bwa",
                "index"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "doc": "BWT construction algorithm: bwtsw or is (Default: auto)\n",
                    "id": "#bwa-index.cwl/algorithm"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "doc": "Block size for the bwtsw algorithm (effective with -a bwtsw) (Default: 10000000)\n",
                    "id": "#bwa-index.cwl/block_size"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 4
                    },
                    "id": "#bwa-index.cwl/sequences"
                }
            ],
            "doc": "Usage:   bwa index [options] <in.fasta>\n\nOptions: -a STR    BWT construction algorithm: bwtsw or is [auto]\n         -p STR    prefix of the index [same as fasta name]\n         -b INT    block size for the bwtsw algorithm (effective with -a bwtsw) [10000000]\n         -6        index files named as <in.fasta>.64.* instead of <in.fasta>.*\n\nWarning: `-a bwtsw' does not work for short genomes, while `-a is' and\n         `-a div' do not work not for long genomes.\n",
            "id": "#bwa-index.cwl",
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.sequences.basename)"
                    },
                    "id": "#bwa-index.cwl/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/bwa:0.7.17--ha92aebf_3",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "bwa",
                "mem"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int"
                        }
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-I",
                        "itemSeparator": ","
                    },
                    "id": "#bwa-mem.cwl/min_std_max_min"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-k"
                    },
                    "doc": "-k INT        minimum seed length [19]",
                    "id": "#bwa-mem.cwl/minimum_seed_length"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "aln-se.sam",
                    "id": "#bwa-mem.cwl/output_filename"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#bwa-mem.cwl/reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa-mem.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "-t INT        number of threads [1]",
                    "id": "#bwa-mem.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#bwa-mem.cwl/output"
                }
            ],
            "doc": "Usage: bwa mem [options] <idxbase> <in1.fq> [in2.fq]\n\nAlgorithm options:\n       -w INT        band width for banded alignment [100]\n       -d INT        off-diagonal X-dropoff [100]\n       -r FLOAT      look for internal seeds inside a seed longer than {-k} * FLOAT [1.5]\n       -y INT        seed occurrence for the 3rd round seeding [20]\n       -c INT        skip seeds with more than INT occurrences [500]\n       -D FLOAT      drop chains shorter than FLOAT fraction of the longest overlapping chain [0.50]\n       -W INT        discard a chain if seeded bases shorter than INT [0]\n       -m INT        perform at most INT rounds of mate rescues for each read [50]\n       -S            skip mate rescue\n       -P            skip pairing; mate rescue performed unless -S also in use\n       -e            discard full-length exact matches\n\nScoring options:\n\n       -A INT        score for a sequence match, which scales options -TdBOELU unless overridden [1]\n       -B INT        penalty for a mismatch [4]\n       -O INT[,INT]  gap open penalties for deletions and insertions [6,6]\n       -E INT[,INT]  gap extension penalty; a gap of size k cost '{-O} + {-E}*k' [1,1]\n       -L INT[,INT]  penalty for 5'- and 3'-end clipping [5,5]\n       -U INT        penalty for an unpaired read pair [17]\n\n       -x STR        read type. Setting -x changes multiple parameters unless overriden [null]\n                     pacbio: -k17 -W40 -r10 -A1 -B1 -O1 -E1 -L0  (PacBio reads to ref)\n                     ont2d: -k14 -W20 -r10 -A1 -B1 -O1 -E1 -L0  (Oxford Nanopore 2D-reads to ref)\n                     intractg: -B9 -O16 -L5  (intra-species contigs to ref)\n\nInput/output options:\n\n       -p            smart pairing (ignoring in2.fq)\n       -R STR        read group header line such as '@RG\\tID:foo\\tSM:bar' [null]\n       -H STR/FILE   insert STR to header if it starts with @; or insert lines in FILE [null]\n       -j            treat ALT contigs as part of the primary assembly (i.e. ignore <idxbase>.alt file)\n\n       -v INT        verbose level: 1=error, 2=warning, 3=message, 4+=debugging [3]\n       -T INT        minimum score to output [30]\n       -h INT[,INT]  if there are <INT hits with score >80% of the max score, output all in XA [5,200]\n       -a            output all alignments for SE or unpaired PE\n       -C            append FASTA/FASTQ comment to SAM output\n       -V            output the reference FASTA header in the XR tag\n       -Y            use soft clipping for supplementary alignments\n       -M            mark shorter split hits as secondary\n\n       -I FLOAT[,FLOAT[,INT[,INT]]]\n                     specify the mean, standard deviation (10% of the mean if absent), max\n                     (4 sigma from the mean if absent) and min of the insert size distribution.\n                     FR orientation only. [inferred]\n\nNote: Please read the man page for detailed description of the command line and options.\n",
            "stdout": "$(inputs.output_filename)",
            "id": "#bwa-mem.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "metabat/metabat:latest",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "jgi_summarize_bam_contig_depths"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcWindow"
                    },
                    "doc": "The sliding window size for GC calculations\n",
                    "id": "#metabat-jgi-summarise.cwl/gcWindow"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--includeEdgeBases"
                    },
                    "doc": "When calculating depth & variance, include the 1-readlength edges (off by default)\n",
                    "id": "#metabat-jgi-summarise.cwl/includeEdgeBases"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "One or more bam files\n",
                    "id": "#metabat-jgi-summarise.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maxEdgeBases"
                    },
                    "doc": "When calculating depth & variance, and not --includeEdgeBases, the maximum length (default:75)\n",
                    "id": "#metabat-jgi-summarise.cwl/maxEdgeBases"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minContigDepth"
                    },
                    "doc": "The minimum depth along contig at which to break the contig\n",
                    "id": "#metabat-jgi-summarise.cwl/minContigDepth"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minContigLength"
                    },
                    "doc": "The mimimum length of contig to include for mapping and shredding\n",
                    "id": "#metabat-jgi-summarise.cwl/minContigLength"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minMapQual"
                    },
                    "doc": "The minimum mapping quality necessary to count the read as mapped (default: 0)\n",
                    "id": "#metabat-jgi-summarise.cwl/minMapQual"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--noIntraDepthVariance"
                    },
                    "doc": "Do not include variance from mean depth along the contig\n",
                    "id": "#metabat-jgi-summarise.cwl/noIntraDepthVariance"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--outputDepth"
                    },
                    "doc": "The file to put the contig by bam depth matrix (default: STDOUT)\n",
                    "id": "#metabat-jgi-summarise.cwl/outputDepth"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--outputGC"
                    },
                    "doc": "The file to print the gc coverage histogram\n",
                    "id": "#metabat-jgi-summarise.cwl/outputGC"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcWindow"
                    },
                    "doc": "The file to print the perfect kmer counts\n",
                    "id": "#metabat-jgi-summarise.cwl/outputKmers"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--outputGC"
                    },
                    "doc": "The file to print the per read statistics\n",
                    "id": "#metabat-jgi-summarise.cwl/outputReadStats"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--pairedContigs"
                    },
                    "doc": "The file to output the sparse matrix of contigs which paired reads span (default: none)\n",
                    "id": "#metabat-jgi-summarise.cwl/pairedContigs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--percentIdentity"
                    },
                    "doc": "The minimum end-to-end % identity of qualifying reads (default: 97)\n",
                    "id": "#metabat-jgi-summarise.cwl/percentIdentity"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showDepth"
                    },
                    "doc": "Output a .depth file per bam for each contig base\n",
                    "id": "#metabat-jgi-summarise.cwl/showDepth"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--shredDepth"
                    },
                    "doc": "The depth to generate overlapping shreds\n",
                    "id": "#metabat-jgi-summarise.cwl/shredDepth"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--shredLength"
                    },
                    "doc": "The maximum length of the shreds\n",
                    "id": "#metabat-jgi-summarise.cwl/shredLength"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--unmappedFastq"
                    },
                    "doc": "The prefix to output unmapped reads from each bam file suffixed by 'bamfile.bam.fastq.gz'\n",
                    "id": "#metabat-jgi-summarise.cwl/unmappedFastq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--weightMapQual"
                    },
                    "doc": "Weight per-base depth based on the MQ of the read (i.e uniqueness) (default: 0.0 (disabled))\n",
                    "id": "#metabat-jgi-summarise.cwl/weightMapQual"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.outputDepth)"
                    },
                    "id": "#metabat-jgi-summarise.cwl/output"
                }
            ],
            "doc": "Usage: jgi_summarize_bam_contig_depths <options> sortedBam1 [ sortedBam2 ...]\nwhere options include:\n    --outputDepth       arg  The file to put the contig by bam depth matrix (default: STDOUT)\n    --percentIdentity   arg  The minimum end-to-end % identity of qualifying reads (default: 97)\n    --pairedContigs     arg  The file to output the sparse matrix of contigs which paired reads span (default: none)\n    --unmappedFastq     arg  The prefix to output unmapped reads from each bam file suffixed by 'bamfile.bam.fastq.gz'\n    --noIntraDepthVariance   Do not include variance from mean depth along the contig\n    --showDepth              Output a .depth file per bam for each contig base\n    --minMapQual        arg  The minimum mapping quality necessary to count the read as mapped (default: 0)\n    --weightMapQual     arg  Weight per-base depth based on the MQ of the read (i.e uniqueness) (default: 0.0 (disabled))\n    --includeEdgeBases       When calculating depth & variance, include the 1-readlength edges (off by default)\n    --maxEdgeBases           When calculating depth & variance, and not --includeEdgeBases, the maximum length (default:75)\n    --referenceFasta    arg  The reference file.  (It must be the same fasta that bams used)\n\nOptions that require a --referenceFasta\n    --outputGC          arg  The file to print the gc coverage histogram\n    --gcWindow          arg  The sliding window size for GC calculations\n    --outputReadStats   arg  The file to print the per read statistics\n    --outputKmers       arg  The file to print the perfect kmer counts\n\nOptions to control shredding contigs that are under represented by the reads\n    --shredLength       arg  The maximum length of the shreds\n    --shredDepth        arg  The depth to generate overlapping shreds\n    --minContigLength   arg  The mimimum length of contig to include for mapping and shredding\n    --minContigDepth    arg  The minimum depth along contig at which to break the contig\n",
            "id": "#metabat-jgi-summarise.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "migueldboland/cwl-assembly-readfq",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/kseq_fastq_base"
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#readfq.cwl/raw_reads"
                }
            ],
            "stdout": "base_count.txt",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "base_count.txt",
                        "loadContents": true,
                        "outputEval": "$(parseInt(self[0].contents))"
                    },
                    "id": "#readfq.cwl/base_count"
                }
            ],
            "doc": "usage: kseq_fastq_base input.fastq.gz [input2.fastq.gz input3.fastq.gz ...]\n\nScript to calculate base count of fastq files.\n\npositional arguments:\n  input.fastq.gz         Raw read files\n",
            "id": "#readfq.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        "$(inputs.alignments)"
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "index",
                "-b"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "$(self.basename)"
                    },
                    "label": "Input bam file.",
                    "id": "#samtools-index.cwl/alignments"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "outputBinding": {
                        "glob": "$(inputs.alignments.basename)"
                    },
                    "doc": "The index file",
                    "id": "#samtools-index.cwl/alignments_with_index"
                }
            ],
            "doc": "samtools-index.cwl is developed for CWL consortium\n",
            "id": "#samtools-index.cwl",
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-index.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "id": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    },
                    "doc": "Set compression level, from 0 (uncompressed) to 9 (best)\n",
                    "id": "#samtools-sort.cwl/compression_level"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Input bam file.",
                    "id": "#samtools-sort.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "doc": "Set maximum memory per thread; suffix K/M/G recognized [768M]\n",
                    "id": "#samtools-sort.cwl/memory"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "doc": "Desired output filename.",
                    "id": "#samtools-sort.cwl/output_name"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "doc": "Sort by read names (i.e., the QNAME field) rather than by chromosomal coordinates.",
                    "id": "#samtools-sort.cwl/sort_by_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "doc": "Set number of sorting and compression threads [1]",
                    "id": "#samtools-sort.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#samtools-sort.cwl/sorted"
                }
            ],
            "doc": "samtools-sort.cwl is developed for CWL consortium\n  Usage: samtools sort [options...] [in.bam]\n  Options:\n    -l INT     Set compression level, from 0 (uncompressed) to 9 (best)\n    -m INT     Set maximum memory per thread; suffix K/M/G recognized [768M]\n    -n         Sort by read name\n    -o FILE    Write final output to FILE rather than standard output\n    -O FORMAT  Write output as FORMAT ('sam'/'bam'/'cram')   (either -O or\n    -T PREFIX  Write temporary files to PREFIX.nnnn.bam       -T is required)\n    -@ INT     Set number of sorting and compression threads [1]\n\n  Legacy usage: samtools sort [options...] <in.bam> <out.prefix>\n  Options:\n    -f         Use <out.prefix> as full final filename rather than prefix\n    -o         Write final output to stdout rather than <out.prefix>.bam\n    -l,m,n,@   Similar to corresponding options above\n",
            "id": "#samtools-sort.cwl",
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/sameAs": [
                    {
                        "$import": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center",
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ]
                    }
                ]
            }
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "quay.io/biocontainers/samtools:1.9--h46bd0b3_0",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#samtools-view.cwl/bedoverlap",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-L"
                    },
                    "doc": "only include reads overlapping this BED FILE [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/cigar",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-m"
                    },
                    "doc": "only include reads with number of CIGAR operations\nconsuming query sequence >= INT [0]\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/collapsecigar",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-B"
                    },
                    "doc": "collapse the backward CIGAR operation\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/count",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "print only the count of matching records\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/fastcompression",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-1"
                    },
                    "doc": "use fast BAM compression (implies -b)\n"
                },
                {
                    "id": "#samtools-view.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "doc": "Input bam file.\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/isbam",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-b"
                    },
                    "doc": "output in BAM format\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/iscram",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-C"
                    },
                    "doc": "output in CRAM format\n"
                },
                {
                    "id": "#samtools-view.cwl/output_name",
                    "type": "string",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-o"
                    }
                },
                {
                    "id": "#samtools-view.cwl/randomseed",
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    },
                    "doc": "integer part sets seed of random number generator [0];\nrest sets fraction of templates to subsample [no subsampling]\n"
                },
                {
                    "id": "#samtools-view.cwl/readsingroup",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "only include reads in read group STR [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/readsingroupfile",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "only include reads with read group listed in FILE [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/readsinlibrary",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "only include reads in library STR [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/readsquality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "only include reads with mapping quality >= INT [0]\n"
                },
                {
                    "id": "#samtools-view.cwl/readswithbits",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "only include reads with all bits set in INT set in FLAG [0]\n"
                },
                {
                    "id": "#samtools-view.cwl/readswithoutbits",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    },
                    "doc": "only include reads with none of the bits set in INT set in FLAG [0]\n"
                },
                {
                    "id": "#samtools-view.cwl/readtagtostrip",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "read tag to strip (repeatable) [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/referencefasta",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-T"
                    },
                    "doc": "reference sequence FASTA FILE [null]\n"
                },
                {
                    "id": "#samtools-view.cwl/region",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5
                    },
                    "doc": "[region ...]\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/samheader",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-h"
                    },
                    "doc": "include header in SAM output\n"
                },
                {
                    "id": "#samtools-view.cwl/threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-@"
                    },
                    "doc": "number of BAM compression threads [0]\n"
                },
                {
                    "default": false,
                    "id": "#samtools-view.cwl/uncompressed",
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    },
                    "doc": "uncompressed BAM output (implies -b)\n"
                }
            ],
            "outputs": [
                {
                    "id": "#samtools-view.cwl/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    }
                }
            ],
            "baseCommand": [
                "samtools",
                "view",
                "-uS"
            ],
            "doc": "samtools-view.cwl is developed for CWL consortium\n  Usage:   samtools view [options] <in.bam>|<in.sam>|<in.cram> [region ...]\n\n  Options: -b       output BAM\n           -C       output CRAM (requires -T)\n           -1       use fast BAM compression (implies -b)\n           -u       uncompressed BAM output (implies -b)\n           -h       include header in SAM output\n           -H       print SAM header only (no alignments)\n           -c       print only the count of matching records\n           -o FILE  output file name [stdout]\n           -U FILE  output reads not selected by filters to FILE [null]\n           -t FILE  FILE listing reference names and lengths (see long help) [null]\n           -T FILE  reference sequence FASTA FILE [null]\n           -L FILE  only include reads overlapping this BED FILE [null]\n           -r STR   only include reads in read group STR [null]\n           -R FILE  only include reads with read group listed in FILE [null]\n           -q INT   only include reads with mapping quality >= INT [0]\n           -l STR   only include reads in library STR [null]\n           -m INT   only include reads with number of CIGAR operations\n                    consuming query sequence >= INT [0]\n           -f INT   only include reads with all bits set in INT set in FLAG [0]\n           -F INT   only include reads with none of the bits set in INT\n                    set in FLAG [0]\n           -x STR   read tag to strip (repeatable) [null]\n           -B       collapse the backward CIGAR operation\n           -s FLOAT integer part sets seed of random number generator [0];\n                    rest sets fraction of templates to subsample [no subsampling]\n           -@ INT   number of BAM compression threads [0]\n",
            "id": "#samtools-view.cwl",
            "http://schema.org/author": {
                "class": "http://schema.org/Person",
                "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                "http://schema.org/name": "Andrey Kartashov",
                "http://schema.org/sameAs": [
                    {
                        "$import": "#0000-0001-9102-5681"
                    }
                ],
                "http://schema.org/worksFor": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/department": [
                            {
                                "class": "http://schema.org/Organization",
                                "http://schema.org/name": "Barski Lab"
                            }
                        ],
                        "http://schema.org/location": "3333 Burnet Ave, Cincinnati, OH 45229-3026",
                        "http://schema.org/name": "Cincinnati Children's Hospital Medical Center"
                    }
                ]
            },
            "http://schema.org/codeRepository": "https://github.com/common-workflow-language/workflows",
            "http://schema.org/downloadUrl": "https://github.com/common-workflow-language/workflows/blob/master/tools/samtools-view.cwl",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "migueldboland/cwl-assembly-stats-report:latest",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/gen_stats_report.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#stats-report.cwl/assembler"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#stats-report.cwl/base_count"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#stats-report.cwl/coverage_file"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#stats-report.cwl/min_contig_length"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#stats-report.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#stats-report.cwl/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#stats-report.cwl/logfile"
                }
            ],
            "doc": "usage: gen_coverage_report.py [-h] output coverage_file base_count\n\nScript to calculate coverage from coverage.tab file and output report\n\npositional arguments:\n  output         Output file\n  coverage_file  Coverage.tab file\n  base_count     Sum of base count for all input files\n\noptional arguments:\n  -h, --help     show this help message and exit\n",
            "id": "#stats-report.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/assembler"
                },
                {
                    "type": "int",
                    "id": "#main/min_contig_length"
                },
                {
                    "type": "string",
                    "id": "#main/output_dest"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/reads"
                },
                {
                    "type": "File",
                    "id": "#main/sequences"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bwa_index/output",
                    "id": "#main/bwa_index_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bwa_mem/output",
                    "id": "#main/bwa_mem_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/stats_report/logfile",
                    "id": "#main/logfile"
                },
                {
                    "type": "File",
                    "outputSource": "#main/metabat_jgi/output",
                    "id": "#main/metabat_coverage_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_index/alignments_with_index",
                    "id": "#main/samtools_index_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_sort/sorted",
                    "id": "#main/samtools_sort_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/samtools_view/output",
                    "id": "#main/samtools_view_output"
                }
            ],
            "steps": [
                {
                    "run": "#bwa-index.cwl",
                    "in": [
                        {
                            "source": "#main/sequences",
                            "id": "#main/bwa_index/sequences"
                        }
                    ],
                    "out": [
                        "#main/bwa_index/output"
                    ],
                    "id": "#main/bwa_index"
                },
                {
                    "run": "#bwa-mem.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/reads"
                            ],
                            "id": "#main/bwa_mem/reads"
                        },
                        {
                            "source": "#main/bwa_index/output",
                            "id": "#main/bwa_mem/reference"
                        }
                    ],
                    "out": [
                        "#main/bwa_mem/output"
                    ],
                    "id": "#main/bwa_mem"
                },
                {
                    "run": "#metabat-jgi-summarise.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_index/alignments_with_index",
                            "id": "#main/metabat_jgi/input"
                        },
                        {
                            "default": "coverage.tab",
                            "id": "#main/metabat_jgi/outputDepth"
                        }
                    ],
                    "out": [
                        "#main/metabat_jgi/output"
                    ],
                    "id": "#main/metabat_jgi"
                },
                {
                    "run": "#readfq.cwl",
                    "in": [
                        {
                            "source": "#main/reads",
                            "id": "#main/readfq/raw_reads"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/readfq/base_count"
                        }
                    ],
                    "id": "#main/readfq"
                },
                {
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_sort/sorted",
                            "id": "#main/samtools_index/alignments"
                        }
                    ],
                    "out": [
                        "#main/samtools_index/alignments_with_index"
                    ],
                    "id": "#main/samtools_index"
                },
                {
                    "run": "#samtools-sort.cwl",
                    "in": [
                        {
                            "source": "#main/samtools_view/output",
                            "id": "#main/samtools_sort/input"
                        },
                        {
                            "default": "sorted.bam",
                            "id": "#main/samtools_sort/output_name"
                        }
                    ],
                    "out": [
                        "#main/samtools_sort/sorted"
                    ],
                    "id": "#main/samtools_sort"
                },
                {
                    "run": "#samtools-view.cwl",
                    "in": [
                        {
                            "source": "#main/bwa_mem/output",
                            "id": "#main/samtools_view/input"
                        },
                        {
                            "default": "unsorted.bam",
                            "id": "#main/samtools_view/output_name"
                        },
                        {
                            "default": true,
                            "id": "#main/samtools_view/uncompressed"
                        },
                        {
                            "default": true,
                            "id": "#main/samtools_view/unselected_output_reads"
                        }
                    ],
                    "out": [
                        "#main/samtools_view/output"
                    ],
                    "id": "#main/samtools_view"
                },
                {
                    "run": "#stats-report.cwl",
                    "in": [
                        {
                            "source": "#main/assembler",
                            "id": "#main/stats_report/assembler"
                        },
                        {
                            "source": "#main/readfq/base_count",
                            "id": "#main/stats_report/base_count"
                        },
                        {
                            "source": "#main/metabat_jgi/output",
                            "id": "#main/stats_report/coverage_file"
                        },
                        {
                            "source": "#main/min_contig_length",
                            "id": "#main/stats_report/min_contig_length"
                        },
                        {
                            "default": "output.json",
                            "id": "#main/stats_report/output"
                        },
                        {
                            "source": "#main/sequences",
                            "id": "#main/stats_report/sequences"
                        }
                    ],
                    "out": [
                        "#main/stats_report/logfile"
                    ],
                    "id": "#main/stats_report"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
